@@ -132,7 +132,6 @@ static const char *aa_vbgr_xpm[] = {
 
 static gboolean setting_model = FALSE;
 static gboolean setting_itheme_model = FALSE;
-static gboolean initial_scroll = TRUE;
 static gboolean is_running = FALSE;
 static gchar *current_theme = NULL;
 static gchar *current_icon_theme = NULL;
@@ -285,13 +284,16 @@ static void read_themes(Itf * dialog)
     GList *list;
     GtkTreeModel *model;
     GtkTreeView *tree_view;
+    GtkTreePath *path;
+    GtkTreeIter iter;
+    GtkTreeIter iter_found;
     gint i = 0;
     gboolean current_theme_found = FALSE;
-    GtkTreeRowReference *row_ref = NULL;
+
 
     gtk_theme_list = theme_common_get_list(gtk_theme_list);
     tree_view = GTK_TREE_VIEW(dialog->theme_treeview);
-    model = gtk_tree_view_get_model(tree_view);
+    model = gtk_tree_view_get_model(GTK_TREE_VIEW (tree_view));
 
     setting_model = TRUE;
     gtk_list_store_clear(GTK_LIST_STORE(model));
@@ -302,7 +304,6 @@ static void read_themes(Itf * dialog)
     for(list = gtk_theme_list; list; list = list->next)
     {
         ThemeInfo *info = list->data;
-        GtkTreeIter iter;
 
         if(!info->has_gtk)
             continue;
@@ -312,10 +313,8 @@ static void read_themes(Itf * dialog)
 
         if(strcmp(current_theme, info->name) == 0)
         {
-            GtkTreePath *path = gtk_tree_model_get_path(model, &iter);
-            row_ref = gtk_tree_row_reference_new(model, path);
-            gtk_tree_path_free(path);
             current_theme_found = TRUE;
+            iter_found = iter;
         }
 
         if(i == MAX_ELEMENTS_BEFORE_SCROLLING)
@@ -330,32 +329,17 @@ static void read_themes(Itf * dialog)
 
     if(!current_theme_found)
     {
-        GtkTreeIter iter;
-        GtkTreePath *path;
-
         gtk_list_store_prepend(GTK_LIST_STORE(model), &iter);
         gtk_list_store_set(GTK_LIST_STORE(model), &iter, THEME_NAME_COLUMN, DEFAULT_THEME, -1);
-
-        path = gtk_tree_model_get_path(model, &iter);
-        row_ref = gtk_tree_row_reference_new(model, path);
-        gtk_tree_path_free(path);
+        iter_found = iter;
     }
 
-    if(row_ref)
+    path = gtk_tree_model_get_path(model, &iter_found);
+    if (path)
     {
-        GtkTreePath *path;
-
-        path = gtk_tree_row_reference_get_path(row_ref);
-        gtk_tree_view_set_cursor(tree_view, path, NULL, FALSE);
-
-        if(initial_scroll)
-        {
-            gtk_tree_view_scroll_to_cell(tree_view, path, NULL, TRUE, 0.5, 0.0);
-            initial_scroll = FALSE;
-        }
-
+        gtk_tree_view_set_cursor(GTK_TREE_VIEW (tree_view), path, NULL, FALSE);
+        gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW (tree_view), path, NULL, TRUE, 0.5, 0.0);
         gtk_tree_path_free(path);
-        gtk_tree_row_reference_free(row_ref);
     }
     setting_model = FALSE;
 }
@@ -366,9 +350,11 @@ static void read_icon_themes(Itf * dialog)
     gchar **icon_theme_dirs;
     GtkTreeModel *model;
     GtkTreeView *tree_view;
+    GtkTreePath *path;
+    GtkTreeIter iter;
+    GtkTreeIter iter_found;
     gint i, j = 0;
     gboolean current_theme_found = FALSE;
-    GtkTreeRowReference *row_ref = NULL;
     GDir *dir;
     const gchar *file;
 
@@ -436,10 +422,8 @@ static void read_icon_themes(Itf * dialog)
 
             if(strcmp(current_icon_theme, file) == 0)
             {
-                GtkTreePath *path = gtk_tree_model_get_path(model, &iter);
-                row_ref = gtk_tree_row_reference_new(model, path);
-                gtk_tree_path_free(path);
                 current_theme_found = TRUE;
+                iter_found = iter;
             }
 
             if(j == MAX_ELEMENTS_BEFORE_SCROLLING)
@@ -459,32 +443,17 @@ static void read_icon_themes(Itf * dialog)
 
     if(!current_theme_found)
     {
-        GtkTreeIter iter;
-        GtkTreePath *path;
-
         gtk_list_store_prepend(GTK_LIST_STORE(model), &iter);
         gtk_list_store_set(GTK_LIST_STORE(model), &iter, THEME_NAME_COLUMN, DEFAULT_ICON_THEME, THEME_NAME_COLUMN + 1, DEFAULT_ICON_THEME, -1);
-
-        path = gtk_tree_model_get_path(model, &iter);
-        row_ref = gtk_tree_row_reference_new(model, path);
-        gtk_tree_path_free(path);
+        iter_found = iter;
     }
 
-    if(row_ref)
+    path = gtk_tree_model_get_path(model, &iter_found);
+    if (path)
     {
-        GtkTreePath *path;
-
-        path = gtk_tree_row_reference_get_path(row_ref);
-        gtk_tree_view_set_cursor(tree_view, path, NULL, FALSE);
-
-        if(initial_scroll)
-        {
-            gtk_tree_view_scroll_to_cell(tree_view, path, NULL, TRUE, 0.5, 0.0);
-            initial_scroll = FALSE;
-        }
-
+        gtk_tree_view_set_cursor(GTK_TREE_VIEW (tree_view), path, NULL, FALSE);
+        gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW (tree_view), path, NULL, TRUE, 0.5, 0.0);
         gtk_tree_path_free(path);
-        gtk_tree_row_reference_free(row_ref);
     }
     setting_itheme_model = FALSE;
 }
